@@ -92,8 +92,8 @@ class ERA5MonthHour(ERA5Dataset, Cohorts):
         by = (self.time.dt.month.values, self.time.dt.hour.values)
         ret = flox.core._factorize_multiple(
             by,
-            expected_groups=(pd.Index(np.arange(1, 13)), pd.Index(np.arange(1, 25))),
-            by_is_dask=False,
+            (pd.Index(np.arange(1, 13)), pd.Index(np.arange(1, 25))),
+            False,
             reindex=False,
         )
         # Add one so the rechunk code is simpler and makes sense
